@@ -5,8 +5,7 @@ use strict;
 use warnings;
 
 use Moose;
-use Class::Load 0.20 qw(load_class);
-use Data::Dump 'dump';
+use Module::Runtime qw( use_module );
 use MooseX::Aliases;
 use MooseX::StrictConstructor;
 use Try::Tiny;
@@ -16,7 +15,7 @@ use MooseX::Types::Moose qw(Bool HashRef Int Str);
 use MooseX::Types::Common::String qw(NonEmptySimpleStr);
 
 # ABSTRACT:  CyberSource Client object  for Business::OnlinePayment::CyberSource
-our $VERSION = '3.000007'; # VERSION
+our $VERSION = '3.000008'; # VERSION
 
 #### Subroutine Definitions ####
 
@@ -66,7 +65,7 @@ sub _authorize          {
 	}
 
 	my $request         = try {
-		load_class( $class )->new( $data );
+		use_module( $class )->new( $data );
 	}
 	catch {
 		$message = shift;
@@ -137,7 +136,7 @@ sub capture            {
 	Exception::Base->throw( $message ) if $message;
 
 	my $request         = try {
-		load_class( 'Business::CyberSource::Request::Capture' )->new( $data );
+		use_module( 'Business::CyberSource::Request::Capture' )->new( $data );
 	}
 	catch {
 		$message          = shift;
@@ -195,7 +194,7 @@ sub credit             {
 	Exception::Base->throw( $message ) if $message;
 
 	my $request         = try {
-		load_class( 'Business::CyberSource::Request::Credit' )->new( $data );
+		use_module( 'Business::CyberSource::Request::Credit' )->new( $data );
 	}
 	catch {
 		$message          = shift;
@@ -251,7 +250,7 @@ sub auth_reversal {
 	Exception::Base->throw( $message ) if $message;
 
 	my $request         = try {
-		load_class( 'Business::CyberSource::Request::AuthReversal' )->new( $data );
+		use_module( 'Business::CyberSource::Request::AuthReversal' )->new( $data );
 	}
 	catch {
 		$self->set_error_message( "$_" );
@@ -339,9 +338,9 @@ sub _build_client { ## no critic ( Subroutines::ProhibitUnusedPrivateSubroutines
 	my $test                 = $self->test_transaction();
 
 	my $data                 = {
-		username               => $username,
-		password               => $password,
-		production             => ! $test,
+		user => $username,
+		pass => $password,
+		test => $test,
 	};
 
 	my $client               = Business::CyberSource::Client->new( $data );
@@ -626,7 +625,7 @@ Business::OnlinePayment::CyberSource::Client - CyberSource Client object  for Bu
 
 =head1 VERSION
 
-version 3.000007
+version 3.000008
 
 =head1 SYNOPSIS
 
@@ -894,7 +893,7 @@ Returns:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/hgdev/Business-OnlinePayment-CyberSource/issues
+https://github.com/xenoterracide/business-onlinepayment-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -920,7 +919,7 @@ Peter Bowen <peter@bowenfamily.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Hostgator.com.
+This software is copyright (c) 2014 by Hostgator.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
